from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.text_to_combined_search_response_200_output_data_profiles_item_tags_type_0_item import TextToCombinedSearchResponse200OutputDataProfilesItemTagsType0Item
from ..types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Union

if TYPE_CHECKING:
  from ..models.text_to_combined_search_response_200_output_data_profiles_item_tenures_type_0_item import TextToCombinedSearchResponse200OutputDataProfilesItemTenuresType0Item
  from ..models.text_to_combined_search_response_200_output_data_profiles_item_current_job_type_0 import TextToCombinedSearchResponse200OutputDataProfilesItemCurrentJobType0
  from ..models.text_to_combined_search_response_200_output_data_profiles_item_publications_type_0_item import TextToCombinedSearchResponse200OutputDataProfilesItemPublicationsType0Item
  from ..models.text_to_combined_search_response_200_output_data_profiles_item_volunteering_type_0_item import TextToCombinedSearchResponse200OutputDataProfilesItemVolunteeringType0Item
  from ..models.text_to_combined_search_response_200_output_data_profiles_item_courses_type_0_item import TextToCombinedSearchResponse200OutputDataProfilesItemCoursesType0Item
  from ..models.text_to_combined_search_response_200_output_data_profiles_item_articles_type_0_item import TextToCombinedSearchResponse200OutputDataProfilesItemArticlesType0Item
  from ..models.text_to_combined_search_response_200_output_data_profiles_item_projects_type_0_item import TextToCombinedSearchResponse200OutputDataProfilesItemProjectsType0Item
  from ..models.text_to_combined_search_response_200_output_data_profiles_item_custom_data_type_0 import TextToCombinedSearchResponse200OutputDataProfilesItemCustomDataType0
  from ..models.text_to_combined_search_response_200_output_data_profiles_item_inferred_location_type_0 import TextToCombinedSearchResponse200OutputDataProfilesItemInferredLocationType0
  from ..models.text_to_combined_search_response_200_output_data_profiles_item_experiences_type_0_item import TextToCombinedSearchResponse200OutputDataProfilesItemExperiencesType0Item
  from ..models.text_to_combined_search_response_200_output_data_profiles_item_patents_type_0_item import TextToCombinedSearchResponse200OutputDataProfilesItemPatentsType0Item
  from ..models.text_to_combined_search_response_200_output_data_profiles_item_detailed_education_type_0_item import TextToCombinedSearchResponse200OutputDataProfilesItemDetailedEducationType0Item
  from ..models.text_to_combined_search_response_200_output_data_profiles_item_organizations_type_0_item import TextToCombinedSearchResponse200OutputDataProfilesItemOrganizationsType0Item
  from ..models.text_to_combined_search_response_200_output_data_profiles_item_detailed_work_experiences_type_0_item import TextToCombinedSearchResponse200OutputDataProfilesItemDetailedWorkExperiencesType0Item
  from ..models.text_to_combined_search_response_200_output_data_profiles_item_languages_type_0_item import TextToCombinedSearchResponse200OutputDataProfilesItemLanguagesType0Item
  from ..models.text_to_combined_search_response_200_output_data_profiles_item_certifications_type_0_item import TextToCombinedSearchResponse200OutputDataProfilesItemCertificationsType0Item
  from ..models.text_to_combined_search_response_200_output_data_profiles_item_education_type_0_item import TextToCombinedSearchResponse200OutputDataProfilesItemEducationType0Item





T = TypeVar("T", bound="TextToCombinedSearchResponse200OutputDataProfilesItem")



@_attrs_define
class TextToCombinedSearchResponse200OutputDataProfilesItem:
    """ 
        Attributes:
            primary_slug (str):
            articles (Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemArticlesType0Item']]):
            certifications (Union[None, Unset,
                list['TextToCombinedSearchResponse200OutputDataProfilesItemCertificationsType0Item']]):
            connection_count (Union[None, Unset, float]):
            courses (Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemCoursesType0Item']]):
            dob (Union[None, Unset, str]):
            education (Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemEducationType0Item']]):
            experiences (Union[None, Unset,
                list['TextToCombinedSearchResponse200OutputDataProfilesItemExperiencesType0Item']]):
            first_name (Union[None, Unset, str]):
            follower_count (Union[None, Unset, float]):
            headline (Union[None, Unset, str]):
            industry_name (Union[None, Unset, str]):
            inferred_location (Union['TextToCombinedSearchResponse200OutputDataProfilesItemInferredLocationType0', None,
                Unset]):
            interests (Union[None, Unset, list[str]]):
            last_name (Union[None, Unset, str]):
            locality (Union[None, Unset, str]):
            name (Union[None, Unset, str]):
            patents (Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemPatentsType0Item']]):
            profile_pic (Union[None, Unset, str]):
            projects (Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemProjectsType0Item']]):
            publications (Union[None, Unset,
                list['TextToCombinedSearchResponse200OutputDataProfilesItemPublicationsType0Item']]):
            skills (Union[None, Unset, list[str]]):
            slugs (Union[None, Unset, list[str]]):
            summary (Union[None, Unset, str]):
            url (Union[None, Unset, str]):
            user_id (Union[None, Unset, str]):
            volunteering (Union[None, Unset,
                list['TextToCombinedSearchResponse200OutputDataProfilesItemVolunteeringType0Item']]):
            tenures (Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemTenuresType0Item']]):
            career_began_at (Union[None, Unset, str]):
            tags (Union[None, Unset, list[TextToCombinedSearchResponse200OutputDataProfilesItemTagsType0Item]]):
            entity_urn (Union[None, Unset, str]):
            open_to_work (Union[None, Unset, bool]):
            premium (Union[None, Unset, bool]):
            influencer (Union[None, Unset, bool]):
            organizations (Union[None, Unset,
                list['TextToCombinedSearchResponse200OutputDataProfilesItemOrganizationsType0Item']]):
            entity_urns (Union[None, Unset, list[str]]):
            is_hiring (Union[None, Unset, bool]):
            current_job (Union['TextToCombinedSearchResponse200OutputDataProfilesItemCurrentJobType0', None, Unset]):
            custom_data (Union['TextToCombinedSearchResponse200OutputDataProfilesItemCustomDataType0', None, Unset]):
            relevance_score (Union[None, Unset, float]):
            last_sort_key (Union[None, Unset, str]):
            languages (Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemLanguagesType0Item']]):
            detailed_education (Union[None, Unset,
                list['TextToCombinedSearchResponse200OutputDataProfilesItemDetailedEducationType0Item']]):
            detailed_work_experiences (Union[None, Unset,
                list['TextToCombinedSearchResponse200OutputDataProfilesItemDetailedWorkExperiencesType0Item']]):
     """

    primary_slug: str
    articles: Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemArticlesType0Item']] = UNSET
    certifications: Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemCertificationsType0Item']] = UNSET
    connection_count: Union[None, Unset, float] = UNSET
    courses: Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemCoursesType0Item']] = UNSET
    dob: Union[None, Unset, str] = UNSET
    education: Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemEducationType0Item']] = UNSET
    experiences: Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemExperiencesType0Item']] = UNSET
    first_name: Union[None, Unset, str] = UNSET
    follower_count: Union[None, Unset, float] = UNSET
    headline: Union[None, Unset, str] = UNSET
    industry_name: Union[None, Unset, str] = UNSET
    inferred_location: Union['TextToCombinedSearchResponse200OutputDataProfilesItemInferredLocationType0', None, Unset] = UNSET
    interests: Union[None, Unset, list[str]] = UNSET
    last_name: Union[None, Unset, str] = UNSET
    locality: Union[None, Unset, str] = UNSET
    name: Union[None, Unset, str] = UNSET
    patents: Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemPatentsType0Item']] = UNSET
    profile_pic: Union[None, Unset, str] = UNSET
    projects: Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemProjectsType0Item']] = UNSET
    publications: Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemPublicationsType0Item']] = UNSET
    skills: Union[None, Unset, list[str]] = UNSET
    slugs: Union[None, Unset, list[str]] = UNSET
    summary: Union[None, Unset, str] = UNSET
    url: Union[None, Unset, str] = UNSET
    user_id: Union[None, Unset, str] = UNSET
    volunteering: Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemVolunteeringType0Item']] = UNSET
    tenures: Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemTenuresType0Item']] = UNSET
    career_began_at: Union[None, Unset, str] = UNSET
    tags: Union[None, Unset, list[TextToCombinedSearchResponse200OutputDataProfilesItemTagsType0Item]] = UNSET
    entity_urn: Union[None, Unset, str] = UNSET
    open_to_work: Union[None, Unset, bool] = UNSET
    premium: Union[None, Unset, bool] = UNSET
    influencer: Union[None, Unset, bool] = UNSET
    organizations: Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemOrganizationsType0Item']] = UNSET
    entity_urns: Union[None, Unset, list[str]] = UNSET
    is_hiring: Union[None, Unset, bool] = UNSET
    current_job: Union['TextToCombinedSearchResponse200OutputDataProfilesItemCurrentJobType0', None, Unset] = UNSET
    custom_data: Union['TextToCombinedSearchResponse200OutputDataProfilesItemCustomDataType0', None, Unset] = UNSET
    relevance_score: Union[None, Unset, float] = UNSET
    last_sort_key: Union[None, Unset, str] = UNSET
    languages: Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemLanguagesType0Item']] = UNSET
    detailed_education: Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemDetailedEducationType0Item']] = UNSET
    detailed_work_experiences: Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemDetailedWorkExperiencesType0Item']] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.text_to_combined_search_response_200_output_data_profiles_item_tenures_type_0_item import TextToCombinedSearchResponse200OutputDataProfilesItemTenuresType0Item
        from ..models.text_to_combined_search_response_200_output_data_profiles_item_current_job_type_0 import TextToCombinedSearchResponse200OutputDataProfilesItemCurrentJobType0
        from ..models.text_to_combined_search_response_200_output_data_profiles_item_publications_type_0_item import TextToCombinedSearchResponse200OutputDataProfilesItemPublicationsType0Item
        from ..models.text_to_combined_search_response_200_output_data_profiles_item_volunteering_type_0_item import TextToCombinedSearchResponse200OutputDataProfilesItemVolunteeringType0Item
        from ..models.text_to_combined_search_response_200_output_data_profiles_item_courses_type_0_item import TextToCombinedSearchResponse200OutputDataProfilesItemCoursesType0Item
        from ..models.text_to_combined_search_response_200_output_data_profiles_item_articles_type_0_item import TextToCombinedSearchResponse200OutputDataProfilesItemArticlesType0Item
        from ..models.text_to_combined_search_response_200_output_data_profiles_item_projects_type_0_item import TextToCombinedSearchResponse200OutputDataProfilesItemProjectsType0Item
        from ..models.text_to_combined_search_response_200_output_data_profiles_item_custom_data_type_0 import TextToCombinedSearchResponse200OutputDataProfilesItemCustomDataType0
        from ..models.text_to_combined_search_response_200_output_data_profiles_item_inferred_location_type_0 import TextToCombinedSearchResponse200OutputDataProfilesItemInferredLocationType0
        from ..models.text_to_combined_search_response_200_output_data_profiles_item_experiences_type_0_item import TextToCombinedSearchResponse200OutputDataProfilesItemExperiencesType0Item
        from ..models.text_to_combined_search_response_200_output_data_profiles_item_patents_type_0_item import TextToCombinedSearchResponse200OutputDataProfilesItemPatentsType0Item
        from ..models.text_to_combined_search_response_200_output_data_profiles_item_detailed_education_type_0_item import TextToCombinedSearchResponse200OutputDataProfilesItemDetailedEducationType0Item
        from ..models.text_to_combined_search_response_200_output_data_profiles_item_organizations_type_0_item import TextToCombinedSearchResponse200OutputDataProfilesItemOrganizationsType0Item
        from ..models.text_to_combined_search_response_200_output_data_profiles_item_detailed_work_experiences_type_0_item import TextToCombinedSearchResponse200OutputDataProfilesItemDetailedWorkExperiencesType0Item
        from ..models.text_to_combined_search_response_200_output_data_profiles_item_languages_type_0_item import TextToCombinedSearchResponse200OutputDataProfilesItemLanguagesType0Item
        from ..models.text_to_combined_search_response_200_output_data_profiles_item_certifications_type_0_item import TextToCombinedSearchResponse200OutputDataProfilesItemCertificationsType0Item
        from ..models.text_to_combined_search_response_200_output_data_profiles_item_education_type_0_item import TextToCombinedSearchResponse200OutputDataProfilesItemEducationType0Item
        primary_slug = self.primary_slug

        articles: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.articles, Unset):
            articles = UNSET
        elif isinstance(self.articles, list):
            articles = []
            for articles_type_0_item_data in self.articles:
                articles_type_0_item = articles_type_0_item_data.to_dict()
                articles.append(articles_type_0_item)


        else:
            articles = self.articles

        certifications: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.certifications, Unset):
            certifications = UNSET
        elif isinstance(self.certifications, list):
            certifications = []
            for certifications_type_0_item_data in self.certifications:
                certifications_type_0_item = certifications_type_0_item_data.to_dict()
                certifications.append(certifications_type_0_item)


        else:
            certifications = self.certifications

        connection_count: Union[None, Unset, float]
        if isinstance(self.connection_count, Unset):
            connection_count = UNSET
        else:
            connection_count = self.connection_count

        courses: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.courses, Unset):
            courses = UNSET
        elif isinstance(self.courses, list):
            courses = []
            for courses_type_0_item_data in self.courses:
                courses_type_0_item = courses_type_0_item_data.to_dict()
                courses.append(courses_type_0_item)


        else:
            courses = self.courses

        dob: Union[None, Unset, str]
        if isinstance(self.dob, Unset):
            dob = UNSET
        else:
            dob = self.dob

        education: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.education, Unset):
            education = UNSET
        elif isinstance(self.education, list):
            education = []
            for education_type_0_item_data in self.education:
                education_type_0_item = education_type_0_item_data.to_dict()
                education.append(education_type_0_item)


        else:
            education = self.education

        experiences: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.experiences, Unset):
            experiences = UNSET
        elif isinstance(self.experiences, list):
            experiences = []
            for experiences_type_0_item_data in self.experiences:
                experiences_type_0_item = experiences_type_0_item_data.to_dict()
                experiences.append(experiences_type_0_item)


        else:
            experiences = self.experiences

        first_name: Union[None, Unset, str]
        if isinstance(self.first_name, Unset):
            first_name = UNSET
        else:
            first_name = self.first_name

        follower_count: Union[None, Unset, float]
        if isinstance(self.follower_count, Unset):
            follower_count = UNSET
        else:
            follower_count = self.follower_count

        headline: Union[None, Unset, str]
        if isinstance(self.headline, Unset):
            headline = UNSET
        else:
            headline = self.headline

        industry_name: Union[None, Unset, str]
        if isinstance(self.industry_name, Unset):
            industry_name = UNSET
        else:
            industry_name = self.industry_name

        inferred_location: Union[None, Unset, dict[str, Any]]
        if isinstance(self.inferred_location, Unset):
            inferred_location = UNSET
        elif isinstance(self.inferred_location, TextToCombinedSearchResponse200OutputDataProfilesItemInferredLocationType0):
            inferred_location = self.inferred_location.to_dict()
        else:
            inferred_location = self.inferred_location

        interests: Union[None, Unset, list[str]]
        if isinstance(self.interests, Unset):
            interests = UNSET
        elif isinstance(self.interests, list):
            interests = self.interests


        else:
            interests = self.interests

        last_name: Union[None, Unset, str]
        if isinstance(self.last_name, Unset):
            last_name = UNSET
        else:
            last_name = self.last_name

        locality: Union[None, Unset, str]
        if isinstance(self.locality, Unset):
            locality = UNSET
        else:
            locality = self.locality

        name: Union[None, Unset, str]
        if isinstance(self.name, Unset):
            name = UNSET
        else:
            name = self.name

        patents: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.patents, Unset):
            patents = UNSET
        elif isinstance(self.patents, list):
            patents = []
            for patents_type_0_item_data in self.patents:
                patents_type_0_item = patents_type_0_item_data.to_dict()
                patents.append(patents_type_0_item)


        else:
            patents = self.patents

        profile_pic: Union[None, Unset, str]
        if isinstance(self.profile_pic, Unset):
            profile_pic = UNSET
        else:
            profile_pic = self.profile_pic

        projects: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.projects, Unset):
            projects = UNSET
        elif isinstance(self.projects, list):
            projects = []
            for projects_type_0_item_data in self.projects:
                projects_type_0_item = projects_type_0_item_data.to_dict()
                projects.append(projects_type_0_item)


        else:
            projects = self.projects

        publications: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.publications, Unset):
            publications = UNSET
        elif isinstance(self.publications, list):
            publications = []
            for publications_type_0_item_data in self.publications:
                publications_type_0_item = publications_type_0_item_data.to_dict()
                publications.append(publications_type_0_item)


        else:
            publications = self.publications

        skills: Union[None, Unset, list[str]]
        if isinstance(self.skills, Unset):
            skills = UNSET
        elif isinstance(self.skills, list):
            skills = self.skills


        else:
            skills = self.skills

        slugs: Union[None, Unset, list[str]]
        if isinstance(self.slugs, Unset):
            slugs = UNSET
        elif isinstance(self.slugs, list):
            slugs = self.slugs


        else:
            slugs = self.slugs

        summary: Union[None, Unset, str]
        if isinstance(self.summary, Unset):
            summary = UNSET
        else:
            summary = self.summary

        url: Union[None, Unset, str]
        if isinstance(self.url, Unset):
            url = UNSET
        else:
            url = self.url

        user_id: Union[None, Unset, str]
        if isinstance(self.user_id, Unset):
            user_id = UNSET
        else:
            user_id = self.user_id

        volunteering: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.volunteering, Unset):
            volunteering = UNSET
        elif isinstance(self.volunteering, list):
            volunteering = []
            for volunteering_type_0_item_data in self.volunteering:
                volunteering_type_0_item = volunteering_type_0_item_data.to_dict()
                volunteering.append(volunteering_type_0_item)


        else:
            volunteering = self.volunteering

        tenures: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.tenures, Unset):
            tenures = UNSET
        elif isinstance(self.tenures, list):
            tenures = []
            for tenures_type_0_item_data in self.tenures:
                tenures_type_0_item = tenures_type_0_item_data.to_dict()
                tenures.append(tenures_type_0_item)


        else:
            tenures = self.tenures

        career_began_at: Union[None, Unset, str]
        if isinstance(self.career_began_at, Unset):
            career_began_at = UNSET
        else:
            career_began_at = self.career_began_at

        tags: Union[None, Unset, list[str]]
        if isinstance(self.tags, Unset):
            tags = UNSET
        elif isinstance(self.tags, list):
            tags = []
            for tags_type_0_item_data in self.tags:
                tags_type_0_item = tags_type_0_item_data.value
                tags.append(tags_type_0_item)


        else:
            tags = self.tags

        entity_urn: Union[None, Unset, str]
        if isinstance(self.entity_urn, Unset):
            entity_urn = UNSET
        else:
            entity_urn = self.entity_urn

        open_to_work: Union[None, Unset, bool]
        if isinstance(self.open_to_work, Unset):
            open_to_work = UNSET
        else:
            open_to_work = self.open_to_work

        premium: Union[None, Unset, bool]
        if isinstance(self.premium, Unset):
            premium = UNSET
        else:
            premium = self.premium

        influencer: Union[None, Unset, bool]
        if isinstance(self.influencer, Unset):
            influencer = UNSET
        else:
            influencer = self.influencer

        organizations: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.organizations, Unset):
            organizations = UNSET
        elif isinstance(self.organizations, list):
            organizations = []
            for organizations_type_0_item_data in self.organizations:
                organizations_type_0_item = organizations_type_0_item_data.to_dict()
                organizations.append(organizations_type_0_item)


        else:
            organizations = self.organizations

        entity_urns: Union[None, Unset, list[str]]
        if isinstance(self.entity_urns, Unset):
            entity_urns = UNSET
        elif isinstance(self.entity_urns, list):
            entity_urns = self.entity_urns


        else:
            entity_urns = self.entity_urns

        is_hiring: Union[None, Unset, bool]
        if isinstance(self.is_hiring, Unset):
            is_hiring = UNSET
        else:
            is_hiring = self.is_hiring

        current_job: Union[None, Unset, dict[str, Any]]
        if isinstance(self.current_job, Unset):
            current_job = UNSET
        elif isinstance(self.current_job, TextToCombinedSearchResponse200OutputDataProfilesItemCurrentJobType0):
            current_job = self.current_job.to_dict()
        else:
            current_job = self.current_job

        custom_data: Union[None, Unset, dict[str, Any]]
        if isinstance(self.custom_data, Unset):
            custom_data = UNSET
        elif isinstance(self.custom_data, TextToCombinedSearchResponse200OutputDataProfilesItemCustomDataType0):
            custom_data = self.custom_data.to_dict()
        else:
            custom_data = self.custom_data

        relevance_score: Union[None, Unset, float]
        if isinstance(self.relevance_score, Unset):
            relevance_score = UNSET
        else:
            relevance_score = self.relevance_score

        last_sort_key: Union[None, Unset, str]
        if isinstance(self.last_sort_key, Unset):
            last_sort_key = UNSET
        else:
            last_sort_key = self.last_sort_key

        languages: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.languages, Unset):
            languages = UNSET
        elif isinstance(self.languages, list):
            languages = []
            for languages_type_0_item_data in self.languages:
                languages_type_0_item = languages_type_0_item_data.to_dict()
                languages.append(languages_type_0_item)


        else:
            languages = self.languages

        detailed_education: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.detailed_education, Unset):
            detailed_education = UNSET
        elif isinstance(self.detailed_education, list):
            detailed_education = []
            for detailed_education_type_0_item_data in self.detailed_education:
                detailed_education_type_0_item = detailed_education_type_0_item_data.to_dict()
                detailed_education.append(detailed_education_type_0_item)


        else:
            detailed_education = self.detailed_education

        detailed_work_experiences: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.detailed_work_experiences, Unset):
            detailed_work_experiences = UNSET
        elif isinstance(self.detailed_work_experiences, list):
            detailed_work_experiences = []
            for detailed_work_experiences_type_0_item_data in self.detailed_work_experiences:
                detailed_work_experiences_type_0_item = detailed_work_experiences_type_0_item_data.to_dict()
                detailed_work_experiences.append(detailed_work_experiences_type_0_item)


        else:
            detailed_work_experiences = self.detailed_work_experiences


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "primary_slug": primary_slug,
        })
        if articles is not UNSET:
            field_dict["articles"] = articles
        if certifications is not UNSET:
            field_dict["certifications"] = certifications
        if connection_count is not UNSET:
            field_dict["connection_count"] = connection_count
        if courses is not UNSET:
            field_dict["courses"] = courses
        if dob is not UNSET:
            field_dict["dob"] = dob
        if education is not UNSET:
            field_dict["education"] = education
        if experiences is not UNSET:
            field_dict["experiences"] = experiences
        if first_name is not UNSET:
            field_dict["first_name"] = first_name
        if follower_count is not UNSET:
            field_dict["follower_count"] = follower_count
        if headline is not UNSET:
            field_dict["headline"] = headline
        if industry_name is not UNSET:
            field_dict["industry_name"] = industry_name
        if inferred_location is not UNSET:
            field_dict["inferred_location"] = inferred_location
        if interests is not UNSET:
            field_dict["interests"] = interests
        if last_name is not UNSET:
            field_dict["last_name"] = last_name
        if locality is not UNSET:
            field_dict["locality"] = locality
        if name is not UNSET:
            field_dict["name"] = name
        if patents is not UNSET:
            field_dict["patents"] = patents
        if profile_pic is not UNSET:
            field_dict["profile_pic"] = profile_pic
        if projects is not UNSET:
            field_dict["projects"] = projects
        if publications is not UNSET:
            field_dict["publications"] = publications
        if skills is not UNSET:
            field_dict["skills"] = skills
        if slugs is not UNSET:
            field_dict["slugs"] = slugs
        if summary is not UNSET:
            field_dict["summary"] = summary
        if url is not UNSET:
            field_dict["url"] = url
        if user_id is not UNSET:
            field_dict["user_id"] = user_id
        if volunteering is not UNSET:
            field_dict["volunteering"] = volunteering
        if tenures is not UNSET:
            field_dict["tenures"] = tenures
        if career_began_at is not UNSET:
            field_dict["career_began_at"] = career_began_at
        if tags is not UNSET:
            field_dict["tags"] = tags
        if entity_urn is not UNSET:
            field_dict["entity_urn"] = entity_urn
        if open_to_work is not UNSET:
            field_dict["open_to_work"] = open_to_work
        if premium is not UNSET:
            field_dict["premium"] = premium
        if influencer is not UNSET:
            field_dict["influencer"] = influencer
        if organizations is not UNSET:
            field_dict["organizations"] = organizations
        if entity_urns is not UNSET:
            field_dict["entity_urns"] = entity_urns
        if is_hiring is not UNSET:
            field_dict["is_hiring"] = is_hiring
        if current_job is not UNSET:
            field_dict["current_job"] = current_job
        if custom_data is not UNSET:
            field_dict["custom_data"] = custom_data
        if relevance_score is not UNSET:
            field_dict["relevance_score"] = relevance_score
        if last_sort_key is not UNSET:
            field_dict["last_sort_key"] = last_sort_key
        if languages is not UNSET:
            field_dict["languages"] = languages
        if detailed_education is not UNSET:
            field_dict["detailed_education"] = detailed_education
        if detailed_work_experiences is not UNSET:
            field_dict["detailed_work_experiences"] = detailed_work_experiences

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.text_to_combined_search_response_200_output_data_profiles_item_tenures_type_0_item import TextToCombinedSearchResponse200OutputDataProfilesItemTenuresType0Item
        from ..models.text_to_combined_search_response_200_output_data_profiles_item_current_job_type_0 import TextToCombinedSearchResponse200OutputDataProfilesItemCurrentJobType0
        from ..models.text_to_combined_search_response_200_output_data_profiles_item_publications_type_0_item import TextToCombinedSearchResponse200OutputDataProfilesItemPublicationsType0Item
        from ..models.text_to_combined_search_response_200_output_data_profiles_item_volunteering_type_0_item import TextToCombinedSearchResponse200OutputDataProfilesItemVolunteeringType0Item
        from ..models.text_to_combined_search_response_200_output_data_profiles_item_courses_type_0_item import TextToCombinedSearchResponse200OutputDataProfilesItemCoursesType0Item
        from ..models.text_to_combined_search_response_200_output_data_profiles_item_articles_type_0_item import TextToCombinedSearchResponse200OutputDataProfilesItemArticlesType0Item
        from ..models.text_to_combined_search_response_200_output_data_profiles_item_projects_type_0_item import TextToCombinedSearchResponse200OutputDataProfilesItemProjectsType0Item
        from ..models.text_to_combined_search_response_200_output_data_profiles_item_custom_data_type_0 import TextToCombinedSearchResponse200OutputDataProfilesItemCustomDataType0
        from ..models.text_to_combined_search_response_200_output_data_profiles_item_inferred_location_type_0 import TextToCombinedSearchResponse200OutputDataProfilesItemInferredLocationType0
        from ..models.text_to_combined_search_response_200_output_data_profiles_item_experiences_type_0_item import TextToCombinedSearchResponse200OutputDataProfilesItemExperiencesType0Item
        from ..models.text_to_combined_search_response_200_output_data_profiles_item_patents_type_0_item import TextToCombinedSearchResponse200OutputDataProfilesItemPatentsType0Item
        from ..models.text_to_combined_search_response_200_output_data_profiles_item_detailed_education_type_0_item import TextToCombinedSearchResponse200OutputDataProfilesItemDetailedEducationType0Item
        from ..models.text_to_combined_search_response_200_output_data_profiles_item_organizations_type_0_item import TextToCombinedSearchResponse200OutputDataProfilesItemOrganizationsType0Item
        from ..models.text_to_combined_search_response_200_output_data_profiles_item_detailed_work_experiences_type_0_item import TextToCombinedSearchResponse200OutputDataProfilesItemDetailedWorkExperiencesType0Item
        from ..models.text_to_combined_search_response_200_output_data_profiles_item_languages_type_0_item import TextToCombinedSearchResponse200OutputDataProfilesItemLanguagesType0Item
        from ..models.text_to_combined_search_response_200_output_data_profiles_item_certifications_type_0_item import TextToCombinedSearchResponse200OutputDataProfilesItemCertificationsType0Item
        from ..models.text_to_combined_search_response_200_output_data_profiles_item_education_type_0_item import TextToCombinedSearchResponse200OutputDataProfilesItemEducationType0Item
        d = dict(src_dict)
        primary_slug = d.pop("primary_slug")

        def _parse_articles(data: object) -> Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemArticlesType0Item']]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                articles_type_0 = []
                _articles_type_0 = data
                for articles_type_0_item_data in (_articles_type_0):
                    articles_type_0_item = TextToCombinedSearchResponse200OutputDataProfilesItemArticlesType0Item.from_dict(articles_type_0_item_data)



                    articles_type_0.append(articles_type_0_item)

                return articles_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemArticlesType0Item']], data)

        articles = _parse_articles(d.pop("articles", UNSET))


        def _parse_certifications(data: object) -> Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemCertificationsType0Item']]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                certifications_type_0 = []
                _certifications_type_0 = data
                for certifications_type_0_item_data in (_certifications_type_0):
                    certifications_type_0_item = TextToCombinedSearchResponse200OutputDataProfilesItemCertificationsType0Item.from_dict(certifications_type_0_item_data)



                    certifications_type_0.append(certifications_type_0_item)

                return certifications_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemCertificationsType0Item']], data)

        certifications = _parse_certifications(d.pop("certifications", UNSET))


        def _parse_connection_count(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        connection_count = _parse_connection_count(d.pop("connection_count", UNSET))


        def _parse_courses(data: object) -> Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemCoursesType0Item']]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                courses_type_0 = []
                _courses_type_0 = data
                for courses_type_0_item_data in (_courses_type_0):
                    courses_type_0_item = TextToCombinedSearchResponse200OutputDataProfilesItemCoursesType0Item.from_dict(courses_type_0_item_data)



                    courses_type_0.append(courses_type_0_item)

                return courses_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemCoursesType0Item']], data)

        courses = _parse_courses(d.pop("courses", UNSET))


        def _parse_dob(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        dob = _parse_dob(d.pop("dob", UNSET))


        def _parse_education(data: object) -> Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemEducationType0Item']]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                education_type_0 = []
                _education_type_0 = data
                for education_type_0_item_data in (_education_type_0):
                    education_type_0_item = TextToCombinedSearchResponse200OutputDataProfilesItemEducationType0Item.from_dict(education_type_0_item_data)



                    education_type_0.append(education_type_0_item)

                return education_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemEducationType0Item']], data)

        education = _parse_education(d.pop("education", UNSET))


        def _parse_experiences(data: object) -> Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemExperiencesType0Item']]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                experiences_type_0 = []
                _experiences_type_0 = data
                for experiences_type_0_item_data in (_experiences_type_0):
                    experiences_type_0_item = TextToCombinedSearchResponse200OutputDataProfilesItemExperiencesType0Item.from_dict(experiences_type_0_item_data)



                    experiences_type_0.append(experiences_type_0_item)

                return experiences_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemExperiencesType0Item']], data)

        experiences = _parse_experiences(d.pop("experiences", UNSET))


        def _parse_first_name(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        first_name = _parse_first_name(d.pop("first_name", UNSET))


        def _parse_follower_count(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        follower_count = _parse_follower_count(d.pop("follower_count", UNSET))


        def _parse_headline(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        headline = _parse_headline(d.pop("headline", UNSET))


        def _parse_industry_name(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        industry_name = _parse_industry_name(d.pop("industry_name", UNSET))


        def _parse_inferred_location(data: object) -> Union['TextToCombinedSearchResponse200OutputDataProfilesItemInferredLocationType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                inferred_location_type_0 = TextToCombinedSearchResponse200OutputDataProfilesItemInferredLocationType0.from_dict(data)



                return inferred_location_type_0
            except: # noqa: E722
                pass
            return cast(Union['TextToCombinedSearchResponse200OutputDataProfilesItemInferredLocationType0', None, Unset], data)

        inferred_location = _parse_inferred_location(d.pop("inferred_location", UNSET))


        def _parse_interests(data: object) -> Union[None, Unset, list[str]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                interests_type_0 = cast(list[str], data)

                return interests_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list[str]], data)

        interests = _parse_interests(d.pop("interests", UNSET))


        def _parse_last_name(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        last_name = _parse_last_name(d.pop("last_name", UNSET))


        def _parse_locality(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        locality = _parse_locality(d.pop("locality", UNSET))


        def _parse_name(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        name = _parse_name(d.pop("name", UNSET))


        def _parse_patents(data: object) -> Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemPatentsType0Item']]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                patents_type_0 = []
                _patents_type_0 = data
                for patents_type_0_item_data in (_patents_type_0):
                    patents_type_0_item = TextToCombinedSearchResponse200OutputDataProfilesItemPatentsType0Item.from_dict(patents_type_0_item_data)



                    patents_type_0.append(patents_type_0_item)

                return patents_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemPatentsType0Item']], data)

        patents = _parse_patents(d.pop("patents", UNSET))


        def _parse_profile_pic(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        profile_pic = _parse_profile_pic(d.pop("profile_pic", UNSET))


        def _parse_projects(data: object) -> Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemProjectsType0Item']]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                projects_type_0 = []
                _projects_type_0 = data
                for projects_type_0_item_data in (_projects_type_0):
                    projects_type_0_item = TextToCombinedSearchResponse200OutputDataProfilesItemProjectsType0Item.from_dict(projects_type_0_item_data)



                    projects_type_0.append(projects_type_0_item)

                return projects_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemProjectsType0Item']], data)

        projects = _parse_projects(d.pop("projects", UNSET))


        def _parse_publications(data: object) -> Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemPublicationsType0Item']]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                publications_type_0 = []
                _publications_type_0 = data
                for publications_type_0_item_data in (_publications_type_0):
                    publications_type_0_item = TextToCombinedSearchResponse200OutputDataProfilesItemPublicationsType0Item.from_dict(publications_type_0_item_data)



                    publications_type_0.append(publications_type_0_item)

                return publications_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemPublicationsType0Item']], data)

        publications = _parse_publications(d.pop("publications", UNSET))


        def _parse_skills(data: object) -> Union[None, Unset, list[str]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                skills_type_0 = cast(list[str], data)

                return skills_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list[str]], data)

        skills = _parse_skills(d.pop("skills", UNSET))


        def _parse_slugs(data: object) -> Union[None, Unset, list[str]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                slugs_type_0 = cast(list[str], data)

                return slugs_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list[str]], data)

        slugs = _parse_slugs(d.pop("slugs", UNSET))


        def _parse_summary(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        summary = _parse_summary(d.pop("summary", UNSET))


        def _parse_url(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        url = _parse_url(d.pop("url", UNSET))


        def _parse_user_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        user_id = _parse_user_id(d.pop("user_id", UNSET))


        def _parse_volunteering(data: object) -> Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemVolunteeringType0Item']]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                volunteering_type_0 = []
                _volunteering_type_0 = data
                for volunteering_type_0_item_data in (_volunteering_type_0):
                    volunteering_type_0_item = TextToCombinedSearchResponse200OutputDataProfilesItemVolunteeringType0Item.from_dict(volunteering_type_0_item_data)



                    volunteering_type_0.append(volunteering_type_0_item)

                return volunteering_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemVolunteeringType0Item']], data)

        volunteering = _parse_volunteering(d.pop("volunteering", UNSET))


        def _parse_tenures(data: object) -> Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemTenuresType0Item']]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                tenures_type_0 = []
                _tenures_type_0 = data
                for tenures_type_0_item_data in (_tenures_type_0):
                    tenures_type_0_item = TextToCombinedSearchResponse200OutputDataProfilesItemTenuresType0Item.from_dict(tenures_type_0_item_data)



                    tenures_type_0.append(tenures_type_0_item)

                return tenures_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemTenuresType0Item']], data)

        tenures = _parse_tenures(d.pop("tenures", UNSET))


        def _parse_career_began_at(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        career_began_at = _parse_career_began_at(d.pop("career_began_at", UNSET))


        def _parse_tags(data: object) -> Union[None, Unset, list[TextToCombinedSearchResponse200OutputDataProfilesItemTagsType0Item]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                tags_type_0 = []
                _tags_type_0 = data
                for tags_type_0_item_data in (_tags_type_0):
                    tags_type_0_item = TextToCombinedSearchResponse200OutputDataProfilesItemTagsType0Item(tags_type_0_item_data)



                    tags_type_0.append(tags_type_0_item)

                return tags_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list[TextToCombinedSearchResponse200OutputDataProfilesItemTagsType0Item]], data)

        tags = _parse_tags(d.pop("tags", UNSET))


        def _parse_entity_urn(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        entity_urn = _parse_entity_urn(d.pop("entity_urn", UNSET))


        def _parse_open_to_work(data: object) -> Union[None, Unset, bool]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, bool], data)

        open_to_work = _parse_open_to_work(d.pop("open_to_work", UNSET))


        def _parse_premium(data: object) -> Union[None, Unset, bool]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, bool], data)

        premium = _parse_premium(d.pop("premium", UNSET))


        def _parse_influencer(data: object) -> Union[None, Unset, bool]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, bool], data)

        influencer = _parse_influencer(d.pop("influencer", UNSET))


        def _parse_organizations(data: object) -> Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemOrganizationsType0Item']]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                organizations_type_0 = []
                _organizations_type_0 = data
                for organizations_type_0_item_data in (_organizations_type_0):
                    organizations_type_0_item = TextToCombinedSearchResponse200OutputDataProfilesItemOrganizationsType0Item.from_dict(organizations_type_0_item_data)



                    organizations_type_0.append(organizations_type_0_item)

                return organizations_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemOrganizationsType0Item']], data)

        organizations = _parse_organizations(d.pop("organizations", UNSET))


        def _parse_entity_urns(data: object) -> Union[None, Unset, list[str]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                entity_urns_type_0 = cast(list[str], data)

                return entity_urns_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list[str]], data)

        entity_urns = _parse_entity_urns(d.pop("entity_urns", UNSET))


        def _parse_is_hiring(data: object) -> Union[None, Unset, bool]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, bool], data)

        is_hiring = _parse_is_hiring(d.pop("is_hiring", UNSET))


        def _parse_current_job(data: object) -> Union['TextToCombinedSearchResponse200OutputDataProfilesItemCurrentJobType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                current_job_type_0 = TextToCombinedSearchResponse200OutputDataProfilesItemCurrentJobType0.from_dict(data)



                return current_job_type_0
            except: # noqa: E722
                pass
            return cast(Union['TextToCombinedSearchResponse200OutputDataProfilesItemCurrentJobType0', None, Unset], data)

        current_job = _parse_current_job(d.pop("current_job", UNSET))


        def _parse_custom_data(data: object) -> Union['TextToCombinedSearchResponse200OutputDataProfilesItemCustomDataType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                custom_data_type_0 = TextToCombinedSearchResponse200OutputDataProfilesItemCustomDataType0.from_dict(data)



                return custom_data_type_0
            except: # noqa: E722
                pass
            return cast(Union['TextToCombinedSearchResponse200OutputDataProfilesItemCustomDataType0', None, Unset], data)

        custom_data = _parse_custom_data(d.pop("custom_data", UNSET))


        def _parse_relevance_score(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        relevance_score = _parse_relevance_score(d.pop("relevance_score", UNSET))


        def _parse_last_sort_key(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        last_sort_key = _parse_last_sort_key(d.pop("last_sort_key", UNSET))


        def _parse_languages(data: object) -> Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemLanguagesType0Item']]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                languages_type_0 = []
                _languages_type_0 = data
                for languages_type_0_item_data in (_languages_type_0):
                    languages_type_0_item = TextToCombinedSearchResponse200OutputDataProfilesItemLanguagesType0Item.from_dict(languages_type_0_item_data)



                    languages_type_0.append(languages_type_0_item)

                return languages_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemLanguagesType0Item']], data)

        languages = _parse_languages(d.pop("languages", UNSET))


        def _parse_detailed_education(data: object) -> Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemDetailedEducationType0Item']]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                detailed_education_type_0 = []
                _detailed_education_type_0 = data
                for detailed_education_type_0_item_data in (_detailed_education_type_0):
                    detailed_education_type_0_item = TextToCombinedSearchResponse200OutputDataProfilesItemDetailedEducationType0Item.from_dict(detailed_education_type_0_item_data)



                    detailed_education_type_0.append(detailed_education_type_0_item)

                return detailed_education_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemDetailedEducationType0Item']], data)

        detailed_education = _parse_detailed_education(d.pop("detailed_education", UNSET))


        def _parse_detailed_work_experiences(data: object) -> Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemDetailedWorkExperiencesType0Item']]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                detailed_work_experiences_type_0 = []
                _detailed_work_experiences_type_0 = data
                for detailed_work_experiences_type_0_item_data in (_detailed_work_experiences_type_0):
                    detailed_work_experiences_type_0_item = TextToCombinedSearchResponse200OutputDataProfilesItemDetailedWorkExperiencesType0Item.from_dict(detailed_work_experiences_type_0_item_data)



                    detailed_work_experiences_type_0.append(detailed_work_experiences_type_0_item)

                return detailed_work_experiences_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list['TextToCombinedSearchResponse200OutputDataProfilesItemDetailedWorkExperiencesType0Item']], data)

        detailed_work_experiences = _parse_detailed_work_experiences(d.pop("detailed_work_experiences", UNSET))


        text_to_combined_search_response_200_output_data_profiles_item = cls(
            primary_slug=primary_slug,
            articles=articles,
            certifications=certifications,
            connection_count=connection_count,
            courses=courses,
            dob=dob,
            education=education,
            experiences=experiences,
            first_name=first_name,
            follower_count=follower_count,
            headline=headline,
            industry_name=industry_name,
            inferred_location=inferred_location,
            interests=interests,
            last_name=last_name,
            locality=locality,
            name=name,
            patents=patents,
            profile_pic=profile_pic,
            projects=projects,
            publications=publications,
            skills=skills,
            slugs=slugs,
            summary=summary,
            url=url,
            user_id=user_id,
            volunteering=volunteering,
            tenures=tenures,
            career_began_at=career_began_at,
            tags=tags,
            entity_urn=entity_urn,
            open_to_work=open_to_work,
            premium=premium,
            influencer=influencer,
            organizations=organizations,
            entity_urns=entity_urns,
            is_hiring=is_hiring,
            current_job=current_job,
            custom_data=custom_data,
            relevance_score=relevance_score,
            last_sort_key=last_sort_key,
            languages=languages,
            detailed_education=detailed_education,
            detailed_work_experiences=detailed_work_experiences,
        )


        text_to_combined_search_response_200_output_data_profiles_item.additional_properties = d
        return text_to_combined_search_response_200_output_data_profiles_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.create_saved_search_body_search_params_type_2_type import CreateSavedSearchBodySearchParamsType2Type
from ..types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Union

if TYPE_CHECKING:
  from ..models.create_saved_search_body_search_params_type_2_profile_search_params import CreateSavedSearchBodySearchParamsType2ProfileSearchParams





T = TypeVar("T", bound="CreateSavedSearchBodySearchParamsType2")



@_attrs_define
class CreateSavedSearchBodySearchParamsType2:
    """ profiles

        Attributes:
            type_ (CreateSavedSearchBodySearchParamsType2Type): profiles
            profile_search_params (Union[Unset, CreateSavedSearchBodySearchParamsType2ProfileSearchParams]): The profile
                search params. This is same as our normal profile search api.
            max_profiles (Union[None, Unset, int]): Max profiles to find. Defaults to 10000 if not provided. Default: 10000.
     """

    type_: CreateSavedSearchBodySearchParamsType2Type
    profile_search_params: Union[Unset, 'CreateSavedSearchBodySearchParamsType2ProfileSearchParams'] = UNSET
    max_profiles: Union[None, Unset, int] = 10000
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.create_saved_search_body_search_params_type_2_profile_search_params import CreateSavedSearchBodySearchParamsType2ProfileSearchParams
        type_ = self.type_.value

        profile_search_params: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.profile_search_params, Unset):
            profile_search_params = self.profile_search_params.to_dict()

        max_profiles: Union[None, Unset, int]
        if isinstance(self.max_profiles, Unset):
            max_profiles = UNSET
        else:
            max_profiles = self.max_profiles


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "type": type_,
        })
        if profile_search_params is not UNSET:
            field_dict["profileSearchParams"] = profile_search_params
        if max_profiles is not UNSET:
            field_dict["maxProfiles"] = max_profiles

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.create_saved_search_body_search_params_type_2_profile_search_params import CreateSavedSearchBodySearchParamsType2ProfileSearchParams
        d = dict(src_dict)
        type_ = CreateSavedSearchBodySearchParamsType2Type(d.pop("type"))




        _profile_search_params = d.pop("profileSearchParams", UNSET)
        profile_search_params: Union[Unset, CreateSavedSearchBodySearchParamsType2ProfileSearchParams]
        if isinstance(_profile_search_params,  Unset):
            profile_search_params = UNSET
        else:
            profile_search_params = CreateSavedSearchBodySearchParamsType2ProfileSearchParams.from_dict(_profile_search_params)




        def _parse_max_profiles(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        max_profiles = _parse_max_profiles(d.pop("maxProfiles", UNSET))


        create_saved_search_body_search_params_type_2 = cls(
            type_=type_,
            profile_search_params=profile_search_params,
            max_profiles=max_profiles,
        )


        create_saved_search_body_search_params_type_2.additional_properties = d
        return create_saved_search_body_search_params_type_2

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast, Union
from typing import Union






T = TypeVar("T", bound="PollCombinedSearchResponse200OutputDataType0ItemsItemEmployeeTrendsType0ItemChangesType0Item")



@_attrs_define
class PollCombinedSearchResponse200OutputDataType0ItemsItemEmployeeTrendsType0ItemChangesType0Item:
    """ 
        Attributes:
            count_end (Union[None, Unset, float]):
            count_start (Union[None, Unset, float]):
            months_back (Union[None, Unset, float]):
            end_of_period (Union[None, Unset, str]):
            numeric_change (Union[None, Unset, float]):
            percent_change (Union[None, Unset, float]):
            start_of_period (Union[None, Unset, str]):
     """

    count_end: Union[None, Unset, float] = UNSET
    count_start: Union[None, Unset, float] = UNSET
    months_back: Union[None, Unset, float] = UNSET
    end_of_period: Union[None, Unset, str] = UNSET
    numeric_change: Union[None, Unset, float] = UNSET
    percent_change: Union[None, Unset, float] = UNSET
    start_of_period: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        count_end: Union[None, Unset, float]
        if isinstance(self.count_end, Unset):
            count_end = UNSET
        else:
            count_end = self.count_end

        count_start: Union[None, Unset, float]
        if isinstance(self.count_start, Unset):
            count_start = UNSET
        else:
            count_start = self.count_start

        months_back: Union[None, Unset, float]
        if isinstance(self.months_back, Unset):
            months_back = UNSET
        else:
            months_back = self.months_back

        end_of_period: Union[None, Unset, str]
        if isinstance(self.end_of_period, Unset):
            end_of_period = UNSET
        else:
            end_of_period = self.end_of_period

        numeric_change: Union[None, Unset, float]
        if isinstance(self.numeric_change, Unset):
            numeric_change = UNSET
        else:
            numeric_change = self.numeric_change

        percent_change: Union[None, Unset, float]
        if isinstance(self.percent_change, Unset):
            percent_change = UNSET
        else:
            percent_change = self.percent_change

        start_of_period: Union[None, Unset, str]
        if isinstance(self.start_of_period, Unset):
            start_of_period = UNSET
        else:
            start_of_period = self.start_of_period


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if count_end is not UNSET:
            field_dict["count_end"] = count_end
        if count_start is not UNSET:
            field_dict["count_start"] = count_start
        if months_back is not UNSET:
            field_dict["months_back"] = months_back
        if end_of_period is not UNSET:
            field_dict["end_of_period"] = end_of_period
        if numeric_change is not UNSET:
            field_dict["numeric_change"] = numeric_change
        if percent_change is not UNSET:
            field_dict["percent_change"] = percent_change
        if start_of_period is not UNSET:
            field_dict["start_of_period"] = start_of_period

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        def _parse_count_end(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        count_end = _parse_count_end(d.pop("count_end", UNSET))


        def _parse_count_start(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        count_start = _parse_count_start(d.pop("count_start", UNSET))


        def _parse_months_back(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        months_back = _parse_months_back(d.pop("months_back", UNSET))


        def _parse_end_of_period(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        end_of_period = _parse_end_of_period(d.pop("end_of_period", UNSET))


        def _parse_numeric_change(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        numeric_change = _parse_numeric_change(d.pop("numeric_change", UNSET))


        def _parse_percent_change(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        percent_change = _parse_percent_change(d.pop("percent_change", UNSET))


        def _parse_start_of_period(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        start_of_period = _parse_start_of_period(d.pop("start_of_period", UNSET))


        poll_combined_search_response_200_output_data_type_0_items_item_employee_trends_type_0_item_changes_type_0_item = cls(
            count_end=count_end,
            count_start=count_start,
            months_back=months_back,
            end_of_period=end_of_period,
            numeric_change=numeric_change,
            percent_change=percent_change,
            start_of_period=start_of_period,
        )


        poll_combined_search_response_200_output_data_type_0_items_item_employee_trends_type_0_item_changes_type_0_item.additional_properties = d
        return poll_combined_search_response_200_output_data_type_0_items_item_employee_trends_type_0_item_changes_type_0_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum

class CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesType0RulesItemEmployeeFiltersType0RecentlyHiredType0ItemHiredAtType1WindowType2Which(str, Enum):
    CURRENT = "current"
    PREVIOUS = "previous"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum

class ManuallySpawnSavedSearchRunResponse200ChargeInfoType2Method(str, Enum):
    CHARGED_FOR_ASYNC_PROCESS = "charged-for-async-process"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Union

if TYPE_CHECKING:
  from ..models.sync_combined_search_response_200_output_profiles_item_tenures_type_0_item_date_range import SyncCombinedSearchResponse200OutputProfilesItemTenuresType0ItemDateRange





T = TypeVar("T", bound="SyncCombinedSearchResponse200OutputProfilesItemTenuresType0Item")



@_attrs_define
class SyncCombinedSearchResponse200OutputProfilesItemTenuresType0Item:
    """ 
        Attributes:
            date_range (SyncCombinedSearchResponse200OutputProfilesItemTenuresType0ItemDateRange):
            titles (list[str]):
            localities (list[str]):
            linkedin_company_id (Union[None, Unset, str]):
            company_name (Union[None, Unset, str]):
            range_length_days (Union[None, Unset, float]):
     """

    date_range: 'SyncCombinedSearchResponse200OutputProfilesItemTenuresType0ItemDateRange'
    titles: list[str]
    localities: list[str]
    linkedin_company_id: Union[None, Unset, str] = UNSET
    company_name: Union[None, Unset, str] = UNSET
    range_length_days: Union[None, Unset, float] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.sync_combined_search_response_200_output_profiles_item_tenures_type_0_item_date_range import SyncCombinedSearchResponse200OutputProfilesItemTenuresType0ItemDateRange
        date_range = self.date_range.to_dict()

        titles = self.titles



        localities = self.localities



        linkedin_company_id: Union[None, Unset, str]
        if isinstance(self.linkedin_company_id, Unset):
            linkedin_company_id = UNSET
        else:
            linkedin_company_id = self.linkedin_company_id

        company_name: Union[None, Unset, str]
        if isinstance(self.company_name, Unset):
            company_name = UNSET
        else:
            company_name = self.company_name

        range_length_days: Union[None, Unset, float]
        if isinstance(self.range_length_days, Unset):
            range_length_days = UNSET
        else:
            range_length_days = self.range_length_days


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "date_range": date_range,
            "titles": titles,
            "localities": localities,
        })
        if linkedin_company_id is not UNSET:
            field_dict["linkedin_company_id"] = linkedin_company_id
        if company_name is not UNSET:
            field_dict["company_name"] = company_name
        if range_length_days is not UNSET:
            field_dict["range_length_days"] = range_length_days

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.sync_combined_search_response_200_output_profiles_item_tenures_type_0_item_date_range import SyncCombinedSearchResponse200OutputProfilesItemTenuresType0ItemDateRange
        d = dict(src_dict)
        date_range = SyncCombinedSearchResponse200OutputProfilesItemTenuresType0ItemDateRange.from_dict(d.pop("date_range"))




        titles = cast(list[str], d.pop("titles"))


        localities = cast(list[str], d.pop("localities"))


        def _parse_linkedin_company_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        linkedin_company_id = _parse_linkedin_company_id(d.pop("linkedin_company_id", UNSET))


        def _parse_company_name(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        company_name = _parse_company_name(d.pop("company_name", UNSET))


        def _parse_range_length_days(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        range_length_days = _parse_range_length_days(d.pop("range_length_days", UNSET))


        sync_combined_search_response_200_output_profiles_item_tenures_type_0_item = cls(
            date_range=date_range,
            titles=titles,
            localities=localities,
            linkedin_company_id=linkedin_company_id,
            company_name=company_name,
            range_length_days=range_length_days,
        )


        sync_combined_search_response_200_output_profiles_item_tenures_type_0_item.additional_properties = d
        return sync_combined_search_response_200_output_profiles_item_tenures_type_0_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Union

if TYPE_CHECKING:
  from ..models.create_saved_search_body_search_params_type_2_profile_search_params_keyword_search_options_type_0_fields_to_search_over_type_0 import CreateSavedSearchBodySearchParamsType2ProfileSearchParamsKeywordSearchOptionsType0FieldsToSearchOverType0





T = TypeVar("T", bound="CreateSavedSearchBodySearchParamsType2ProfileSearchParamsKeywordSearchOptionsType0")



@_attrs_define
class CreateSavedSearchBodySearchParamsType2ProfileSearchParamsKeywordSearchOptionsType0:
    """ 
        Attributes:
            fields_to_search_over (Union['CreateSavedSearchBodySearchParamsType2ProfileSearchParamsKeywordSearchOptionsType0
                FieldsToSearchOverType0', None, Unset]):
     """

    fields_to_search_over: Union['CreateSavedSearchBodySearchParamsType2ProfileSearchParamsKeywordSearchOptionsType0FieldsToSearchOverType0', None, Unset] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.create_saved_search_body_search_params_type_2_profile_search_params_keyword_search_options_type_0_fields_to_search_over_type_0 import CreateSavedSearchBodySearchParamsType2ProfileSearchParamsKeywordSearchOptionsType0FieldsToSearchOverType0
        fields_to_search_over: Union[None, Unset, dict[str, Any]]
        if isinstance(self.fields_to_search_over, Unset):
            fields_to_search_over = UNSET
        elif isinstance(self.fields_to_search_over, CreateSavedSearchBodySearchParamsType2ProfileSearchParamsKeywordSearchOptionsType0FieldsToSearchOverType0):
            fields_to_search_over = self.fields_to_search_over.to_dict()
        else:
            fields_to_search_over = self.fields_to_search_over


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if fields_to_search_over is not UNSET:
            field_dict["fieldsToSearchOver"] = fields_to_search_over

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.create_saved_search_body_search_params_type_2_profile_search_params_keyword_search_options_type_0_fields_to_search_over_type_0 import CreateSavedSearchBodySearchParamsType2ProfileSearchParamsKeywordSearchOptionsType0FieldsToSearchOverType0
        d = dict(src_dict)
        def _parse_fields_to_search_over(data: object) -> Union['CreateSavedSearchBodySearchParamsType2ProfileSearchParamsKeywordSearchOptionsType0FieldsToSearchOverType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                fields_to_search_over_type_0 = CreateSavedSearchBodySearchParamsType2ProfileSearchParamsKeywordSearchOptionsType0FieldsToSearchOverType0.from_dict(data)



                return fields_to_search_over_type_0
            except: # noqa: E722
                pass
            return cast(Union['CreateSavedSearchBodySearchParamsType2ProfileSearchParamsKeywordSearchOptionsType0FieldsToSearchOverType0', None, Unset], data)

        fields_to_search_over = _parse_fields_to_search_over(d.pop("fieldsToSearchOver", UNSET))


        create_saved_search_body_search_params_type_2_profile_search_params_keyword_search_options_type_0 = cls(
            fields_to_search_over=fields_to_search_over,
        )


        create_saved_search_body_search_params_type_2_profile_search_params_keyword_search_options_type_0.additional_properties = d
        return create_saved_search_body_search_params_type_2_profile_search_params_keyword_search_options_type_0

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Union

if TYPE_CHECKING:
  from ..models.company_search_body_search_params_employees_type_0_rules_item_employee_filters_type_0_recently_hired_type_0_item import CompanySearchBodySearchParamsEmployeesType0RulesItemEmployeeFiltersType0RecentlyHiredType0Item





T = TypeVar("T", bound="CompanySearchBodySearchParamsEmployeesType0RulesItemEmployeeFiltersType0")



@_attrs_define
class CompanySearchBodySearchParamsEmployeesType0RulesItemEmployeeFiltersType0:
    """ 
        Attributes:
            country_code (Union[None, Unset, list[str]]):
            job_title (Union[None, Unset, list[str]]):
            recently_hired (Union[None, Unset,
                list['CompanySearchBodySearchParamsEmployeesType0RulesItemEmployeeFiltersType0RecentlyHiredType0Item']]):
     """

    country_code: Union[None, Unset, list[str]] = UNSET
    job_title: Union[None, Unset, list[str]] = UNSET
    recently_hired: Union[None, Unset, list['CompanySearchBodySearchParamsEmployeesType0RulesItemEmployeeFiltersType0RecentlyHiredType0Item']] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.company_search_body_search_params_employees_type_0_rules_item_employee_filters_type_0_recently_hired_type_0_item import CompanySearchBodySearchParamsEmployeesType0RulesItemEmployeeFiltersType0RecentlyHiredType0Item
        country_code: Union[None, Unset, list[str]]
        if isinstance(self.country_code, Unset):
            country_code = UNSET
        elif isinstance(self.country_code, list):
            country_code = self.country_code


        else:
            country_code = self.country_code

        job_title: Union[None, Unset, list[str]]
        if isinstance(self.job_title, Unset):
            job_title = UNSET
        elif isinstance(self.job_title, list):
            job_title = self.job_title


        else:
            job_title = self.job_title

        recently_hired: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.recently_hired, Unset):
            recently_hired = UNSET
        elif isinstance(self.recently_hired, list):
            recently_hired = []
            for recently_hired_type_0_item_data in self.recently_hired:
                recently_hired_type_0_item = recently_hired_type_0_item_data.to_dict()
                recently_hired.append(recently_hired_type_0_item)


        else:
            recently_hired = self.recently_hired


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if country_code is not UNSET:
            field_dict["countryCode"] = country_code
        if job_title is not UNSET:
            field_dict["jobTitle"] = job_title
        if recently_hired is not UNSET:
            field_dict["recentlyHired"] = recently_hired

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.company_search_body_search_params_employees_type_0_rules_item_employee_filters_type_0_recently_hired_type_0_item import CompanySearchBodySearchParamsEmployeesType0RulesItemEmployeeFiltersType0RecentlyHiredType0Item
        d = dict(src_dict)
        def _parse_country_code(data: object) -> Union[None, Unset, list[str]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                country_code_type_0 = cast(list[str], data)

                return country_code_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list[str]], data)

        country_code = _parse_country_code(d.pop("countryCode", UNSET))


        def _parse_job_title(data: object) -> Union[None, Unset, list[str]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                job_title_type_0 = cast(list[str], data)

                return job_title_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list[str]], data)

        job_title = _parse_job_title(d.pop("jobTitle", UNSET))


        def _parse_recently_hired(data: object) -> Union[None, Unset, list['CompanySearchBodySearchParamsEmployeesType0RulesItemEmployeeFiltersType0RecentlyHiredType0Item']]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                recently_hired_type_0 = []
                _recently_hired_type_0 = data
                for recently_hired_type_0_item_data in (_recently_hired_type_0):
                    recently_hired_type_0_item = CompanySearchBodySearchParamsEmployeesType0RulesItemEmployeeFiltersType0RecentlyHiredType0Item.from_dict(recently_hired_type_0_item_data)



                    recently_hired_type_0.append(recently_hired_type_0_item)

                return recently_hired_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list['CompanySearchBodySearchParamsEmployeesType0RulesItemEmployeeFiltersType0RecentlyHiredType0Item']], data)

        recently_hired = _parse_recently_hired(d.pop("recentlyHired", UNSET))


        company_search_body_search_params_employees_type_0_rules_item_employee_filters_type_0 = cls(
            country_code=country_code,
            job_title=job_title,
            recently_hired=recently_hired,
        )


        company_search_body_search_params_employees_type_0_rules_item_employee_filters_type_0.additional_properties = d
        return company_search_body_search_params_employees_type_0_rules_item_employee_filters_type_0

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast, Union
from typing import Union






T = TypeVar("T", bound="SyncCombinedSearchBodyProfileParamsStateType0NoneOfType0Item")



@_attrs_define
class SyncCombinedSearchBodyProfileParamsStateType0NoneOfType0Item:
    """ 
        Attributes:
            state_name (str):
            country_code (Union[None, Unset, str]):
     """

    state_name: str
    country_code: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        state_name = self.state_name

        country_code: Union[None, Unset, str]
        if isinstance(self.country_code, Unset):
            country_code = UNSET
        else:
            country_code = self.country_code


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "stateName": state_name,
        })
        if country_code is not UNSET:
            field_dict["countryCode"] = country_code

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        state_name = d.pop("stateName")

        def _parse_country_code(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        country_code = _parse_country_code(d.pop("countryCode", UNSET))


        sync_combined_search_body_profile_params_state_type_0_none_of_type_0_item = cls(
            state_name=state_name,
            country_code=country_code,
        )


        sync_combined_search_body_profile_params_state_type_0_none_of_type_0_item.additional_properties = d
        return sync_combined_search_body_profile_params_state_type_0_none_of_type_0_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum

class SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysNoneType0ItemCountCriteriaType1Type(str, Enum):
    PERCENT_CHANGE = "percent_change"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum

class TextToCombinedSearchResponse200OutputDataProfilesItemTagsType0Item(str, Enum):
    ATTENDED_TOP_GLOBAL_UNIVERSITY = "attended-top-global-university"
    ATTENDED_TOP_US_UNIVERSITY = "attended-top-us-university"
    BOARD_MEMBER = "board-member"
    C_SUITE = "c-suite"
    DECISION_MAKER = "decision-maker"
    DEEP_TECHNICAL_BACKGROUND = "deep-technical-background"
    EXPERIENCED_EXECUTIVE = "experienced-executive"
    FORTUNE_500_EXECUTIVE = "fortune-500-executive"
    INFLUENCER = "influencer"
    MAJOR_TECH_COMPANY_EXPERIENCE = "major-tech-company-experience"
    PHD = "phd"
    RECENTLY_CHANGED_COMPANIES = "recently-changed-companies"
    RECENTLY_PROMOTED = "recently-promoted"
    SECOND_TIME_FOUNDER = "second-time-founder"
    STEALTH_FOUNDER = "stealth-founder"
    STUDENT = "student"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.post_comments_live_fetch_response_200_output_data_item_reactions_by_type_type_0_item_reaction_type_type_1 import PostCommentsLiveFetchResponse200OutputDataItemReactionsByTypeType0ItemReactionTypeType1
from ..models.post_comments_live_fetch_response_200_output_data_item_reactions_by_type_type_0_item_reaction_type_type_2_type_1 import PostCommentsLiveFetchResponse200OutputDataItemReactionsByTypeType0ItemReactionTypeType2Type1
from ..models.post_comments_live_fetch_response_200_output_data_item_reactions_by_type_type_0_item_reaction_type_type_3_type_1 import PostCommentsLiveFetchResponse200OutputDataItemReactionsByTypeType0ItemReactionTypeType3Type1
from ..types import UNSET, Unset
from typing import cast, Union
from typing import Union






T = TypeVar("T", bound="PostCommentsLiveFetchResponse200OutputDataItemReactionsByTypeType0Item")



@_attrs_define
class PostCommentsLiveFetchResponse200OutputDataItemReactionsByTypeType0Item:
    """ 
        Attributes:
            num_reactions (Union[None, Unset, float]):
            reaction_type (Union[None,
                PostCommentsLiveFetchResponse200OutputDataItemReactionsByTypeType0ItemReactionTypeType1,
                PostCommentsLiveFetchResponse200OutputDataItemReactionsByTypeType0ItemReactionTypeType2Type1,
                PostCommentsLiveFetchResponse200OutputDataItemReactionsByTypeType0ItemReactionTypeType3Type1, Unset]): One of
                LinkedIn's reaction types. These match the tooltips on each of LinkedIn's six reaction buttons; for instance,
                'Like' is the blue thumbs-up.
     """

    num_reactions: Union[None, Unset, float] = UNSET
    reaction_type: Union[None, PostCommentsLiveFetchResponse200OutputDataItemReactionsByTypeType0ItemReactionTypeType1, PostCommentsLiveFetchResponse200OutputDataItemReactionsByTypeType0ItemReactionTypeType2Type1, PostCommentsLiveFetchResponse200OutputDataItemReactionsByTypeType0ItemReactionTypeType3Type1, Unset] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        num_reactions: Union[None, Unset, float]
        if isinstance(self.num_reactions, Unset):
            num_reactions = UNSET
        else:
            num_reactions = self.num_reactions

        reaction_type: Union[None, Unset, str]
        if isinstance(self.reaction_type, Unset):
            reaction_type = UNSET
        elif isinstance(self.reaction_type, PostCommentsLiveFetchResponse200OutputDataItemReactionsByTypeType0ItemReactionTypeType1):
            reaction_type = self.reaction_type.value
        elif isinstance(self.reaction_type, PostCommentsLiveFetchResponse200OutputDataItemReactionsByTypeType0ItemReactionTypeType2Type1):
            reaction_type = self.reaction_type.value
        elif isinstance(self.reaction_type, PostCommentsLiveFetchResponse200OutputDataItemReactionsByTypeType0ItemReactionTypeType3Type1):
            reaction_type = self.reaction_type.value
        else:
            reaction_type = self.reaction_type


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if num_reactions is not UNSET:
            field_dict["numReactions"] = num_reactions
        if reaction_type is not UNSET:
            field_dict["reactionType"] = reaction_type

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        def _parse_num_reactions(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        num_reactions = _parse_num_reactions(d.pop("numReactions", UNSET))


        def _parse_reaction_type(data: object) -> Union[None, PostCommentsLiveFetchResponse200OutputDataItemReactionsByTypeType0ItemReactionTypeType1, PostCommentsLiveFetchResponse200OutputDataItemReactionsByTypeType0ItemReactionTypeType2Type1, PostCommentsLiveFetchResponse200OutputDataItemReactionsByTypeType0ItemReactionTypeType3Type1, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                reaction_type_type_1 = PostCommentsLiveFetchResponse200OutputDataItemReactionsByTypeType0ItemReactionTypeType1(data)



                return reaction_type_type_1
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                reaction_type_type_2_type_1 = PostCommentsLiveFetchResponse200OutputDataItemReactionsByTypeType0ItemReactionTypeType2Type1(data)



                return reaction_type_type_2_type_1
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                reaction_type_type_3_type_1 = PostCommentsLiveFetchResponse200OutputDataItemReactionsByTypeType0ItemReactionTypeType3Type1(data)



                return reaction_type_type_3_type_1
            except: # noqa: E722
                pass
            return cast(Union[None, PostCommentsLiveFetchResponse200OutputDataItemReactionsByTypeType0ItemReactionTypeType1, PostCommentsLiveFetchResponse200OutputDataItemReactionsByTypeType0ItemReactionTypeType2Type1, PostCommentsLiveFetchResponse200OutputDataItemReactionsByTypeType0ItemReactionTypeType3Type1, Unset], data)

        reaction_type = _parse_reaction_type(d.pop("reactionType", UNSET))


        post_comments_live_fetch_response_200_output_data_item_reactions_by_type_type_0_item = cls(
            num_reactions=num_reactions,
            reaction_type=reaction_type,
        )


        post_comments_live_fetch_response_200_output_data_item_reactions_by_type_type_0_item.additional_properties = d
        return post_comments_live_fetch_response_200_output_data_item_reactions_by_type_type_0_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum

class CompanySearchBodySearchParamsEmployeeTrendsType0ObeysAnyType0ItemJobFunction(str, Enum):
    ACCOUNTING = "accounting"
    ADMINISTRATIVE = "administrative"
    ARTS_AND_DESIGN = "arts_and_design"
    BUSINESS_DEVELOPMENT = "business_development"
    CONSULTING = "consulting"
    DATA_SCIENCE = "data_science"
    EDUCATION = "education"
    ENGINEERING = "engineering"
    ENTREPRENEURSHIP = "entrepreneurship"
    FINANCE = "finance"
    HUMAN_RESOURCES = "human_resources"
    INFORMATION_TECHNOLOGY = "information_technology"
    LEGAL = "legal"
    MARKETING = "marketing"
    MEDIA_AND_COMMMUNICATION = "media_and_commmunication"
    OPERATIONS = "operations"
    PRODUCT_MANAGEMENT = "product_management"
    SALES = "sales"
    SUPPORT = "support"
    VALUE_0 = "_all_employees"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum

class TextToCompanySearchResponse200OutputSearchParamsAcceleratorsV2Type0NoneOfType0ItemBatchSelectionType1Strategy(str, Enum):
    ONLY_THESE_BATCHES = "only-these-batches"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum

class CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1Status(str, Enum):
    LEFT_STEALTH = "left-stealth"

    def __str__(self) -> str:
        return str(self.value)



from http import HTTPStatus
from typing import Any, Optional, Union, cast

import httpx

from ...client import AuthenticatedClient, Client
from ...types import Response, UNSET
from ... import errors

from ...models.poll_contact_enrichment_result_body import PollContactEnrichmentResultBody
from ...models.poll_contact_enrichment_result_response_200 import PollContactEnrichmentResultResponse200
from ...models.poll_contact_enrichment_result_response_400 import PollContactEnrichmentResultResponse400
from ...models.poll_contact_enrichment_result_response_401 import PollContactEnrichmentResultResponse401
from ...models.poll_contact_enrichment_result_response_402 import PollContactEnrichmentResultResponse402
from ...models.poll_contact_enrichment_result_response_403 import PollContactEnrichmentResultResponse403
from ...models.poll_contact_enrichment_result_response_404 import PollContactEnrichmentResultResponse404
from ...models.poll_contact_enrichment_result_response_429 import PollContactEnrichmentResultResponse429
from ...models.poll_contact_enrichment_result_response_500 import PollContactEnrichmentResultResponse500
from typing import cast



def _get_kwargs(
    *,
    body: PollContactEnrichmentResultBody,

) -> dict[str, Any]:
    headers: dict[str, Any] = {}


    

    

    _kwargs: dict[str, Any] = {
        "method": "post",
        "url": "/v1/contact-details/poll",
    }

    _kwargs["json"] = body.to_dict()


    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs



def _parse_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Optional[Union[PollContactEnrichmentResultResponse200, PollContactEnrichmentResultResponse400, PollContactEnrichmentResultResponse401, PollContactEnrichmentResultResponse402, PollContactEnrichmentResultResponse403, PollContactEnrichmentResultResponse404, PollContactEnrichmentResultResponse429, PollContactEnrichmentResultResponse500]]:
    if response.status_code == 200:
        response_200 = PollContactEnrichmentResultResponse200.from_dict(response.json())



        return response_200

    if response.status_code == 400:
        response_400 = PollContactEnrichmentResultResponse400.from_dict(response.json())



        return response_400

    if response.status_code == 401:
        response_401 = PollContactEnrichmentResultResponse401.from_dict(response.json())



        return response_401

    if response.status_code == 402:
        response_402 = PollContactEnrichmentResultResponse402.from_dict(response.json())



        return response_402

    if response.status_code == 403:
        response_403 = PollContactEnrichmentResultResponse403.from_dict(response.json())



        return response_403

    if response.status_code == 404:
        response_404 = PollContactEnrichmentResultResponse404.from_dict(response.json())



        return response_404

    if response.status_code == 429:
        response_429 = PollContactEnrichmentResultResponse429.from_dict(response.json())



        return response_429

    if response.status_code == 500:
        response_500 = PollContactEnrichmentResultResponse500.from_dict(response.json())



        return response_500

    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Response[Union[PollContactEnrichmentResultResponse200, PollContactEnrichmentResultResponse400, PollContactEnrichmentResultResponse401, PollContactEnrichmentResultResponse402, PollContactEnrichmentResultResponse403, PollContactEnrichmentResultResponse404, PollContactEnrichmentResultResponse429, PollContactEnrichmentResultResponse500]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    body: PollContactEnrichmentResultBody,

) -> Response[Union[PollContactEnrichmentResultResponse200, PollContactEnrichmentResultResponse400, PollContactEnrichmentResultResponse401, PollContactEnrichmentResultResponse402, PollContactEnrichmentResultResponse403, PollContactEnrichmentResultResponse404, PollContactEnrichmentResultResponse429, PollContactEnrichmentResultResponse500]]:
    """ Poll contact details fetching task

     Polls an asynchronous contact detail enrichment task. Call this with the task ID returned from the
    'Start fetching person's contact details' endpoint.

    <span>⚡ <strong>Rate limit:</strong> 240 requests per 1 minute</span>

    Args:
        body (PollContactEnrichmentResultBody):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[PollContactEnrichmentResultResponse200, PollContactEnrichmentResultResponse400, PollContactEnrichmentResultResponse401, PollContactEnrichmentResultResponse402, PollContactEnrichmentResultResponse403, PollContactEnrichmentResultResponse404, PollContactEnrichmentResultResponse429, PollContactEnrichmentResultResponse500]]
     """


    kwargs = _get_kwargs(
        body=body,

    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)

def sync(
    *,
    client: Union[AuthenticatedClient, Client],
    body: PollContactEnrichmentResultBody,

) -> Optional[Union[PollContactEnrichmentResultResponse200, PollContactEnrichmentResultResponse400, PollContactEnrichmentResultResponse401, PollContactEnrichmentResultResponse402, PollContactEnrichmentResultResponse403, PollContactEnrichmentResultResponse404, PollContactEnrichmentResultResponse429, PollContactEnrichmentResultResponse500]]:
    """ Poll contact details fetching task

     Polls an asynchronous contact detail enrichment task. Call this with the task ID returned from the
    'Start fetching person's contact details' endpoint.

    <span>⚡ <strong>Rate limit:</strong> 240 requests per 1 minute</span>

    Args:
        body (PollContactEnrichmentResultBody):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[PollContactEnrichmentResultResponse200, PollContactEnrichmentResultResponse400, PollContactEnrichmentResultResponse401, PollContactEnrichmentResultResponse402, PollContactEnrichmentResultResponse403, PollContactEnrichmentResultResponse404, PollContactEnrichmentResultResponse429, PollContactEnrichmentResultResponse500]
     """


    return sync_detailed(
        client=client,
body=body,

    ).parsed

async def asyncio_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    body: PollContactEnrichmentResultBody,

) -> Response[Union[PollContactEnrichmentResultResponse200, PollContactEnrichmentResultResponse400, PollContactEnrichmentResultResponse401, PollContactEnrichmentResultResponse402, PollContactEnrichmentResultResponse403, PollContactEnrichmentResultResponse404, PollContactEnrichmentResultResponse429, PollContactEnrichmentResultResponse500]]:
    """ Poll contact details fetching task

     Polls an asynchronous contact detail enrichment task. Call this with the task ID returned from the
    'Start fetching person's contact details' endpoint.

    <span>⚡ <strong>Rate limit:</strong> 240 requests per 1 minute</span>

    Args:
        body (PollContactEnrichmentResultBody):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[PollContactEnrichmentResultResponse200, PollContactEnrichmentResultResponse400, PollContactEnrichmentResultResponse401, PollContactEnrichmentResultResponse402, PollContactEnrichmentResultResponse403, PollContactEnrichmentResultResponse404, PollContactEnrichmentResultResponse429, PollContactEnrichmentResultResponse500]]
     """


    kwargs = _get_kwargs(
        body=body,

    )

    response = await client.get_async_httpx_client().request(
        **kwargs
    )

    return _build_response(client=client, response=response)

async def asyncio(
    *,
    client: Union[AuthenticatedClient, Client],
    body: PollContactEnrichmentResultBody,

) -> Optional[Union[PollContactEnrichmentResultResponse200, PollContactEnrichmentResultResponse400, PollContactEnrichmentResultResponse401, PollContactEnrichmentResultResponse402, PollContactEnrichmentResultResponse403, PollContactEnrichmentResultResponse404, PollContactEnrichmentResultResponse429, PollContactEnrichmentResultResponse500]]:
    """ Poll contact details fetching task

     Polls an asynchronous contact detail enrichment task. Call this with the task ID returned from the
    'Start fetching person's contact details' endpoint.

    <span>⚡ <strong>Rate limit:</strong> 240 requests per 1 minute</span>

    Args:
        body (PollContactEnrichmentResultBody):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[PollContactEnrichmentResultResponse200, PollContactEnrichmentResultResponse400, PollContactEnrichmentResultResponse401, PollContactEnrichmentResultResponse402, PollContactEnrichmentResultResponse403, PollContactEnrichmentResultResponse404, PollContactEnrichmentResultResponse429, PollContactEnrichmentResultResponse500]
     """


    return (await asyncio_detailed(
        client=client,
body=body,

    )).parsed



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Union

if TYPE_CHECKING:
  from ..models.kitchen_sink_bulk_profile_response_200_warnings_type_0_item import KitchenSinkBulkProfileResponse200WarningsType0Item
  from ..models.kitchen_sink_bulk_profile_response_200_charge_info_type_0 import KitchenSinkBulkProfileResponse200ChargeInfoType0
  from ..models.kitchen_sink_bulk_profile_response_200_charge_info_type_3 import KitchenSinkBulkProfileResponse200ChargeInfoType3
  from ..models.kitchen_sink_bulk_profile_response_200_charge_info_type_1 import KitchenSinkBulkProfileResponse200ChargeInfoType1
  from ..models.kitchen_sink_bulk_profile_response_200_output import KitchenSinkBulkProfileResponse200Output
  from ..models.kitchen_sink_bulk_profile_response_200_charge_info_type_2 import KitchenSinkBulkProfileResponse200ChargeInfoType2





T = TypeVar("T", bound="KitchenSinkBulkProfileResponse200")



@_attrs_define
class KitchenSinkBulkProfileResponse200:
    """ 
        Attributes:
            output (KitchenSinkBulkProfileResponse200Output):
            charge_info (Union['KitchenSinkBulkProfileResponse200ChargeInfoType0',
                'KitchenSinkBulkProfileResponse200ChargeInfoType1', 'KitchenSinkBulkProfileResponse200ChargeInfoType2',
                'KitchenSinkBulkProfileResponse200ChargeInfoType3']):
            warnings (Union[None, Unset, list['KitchenSinkBulkProfileResponse200WarningsType0Item']]): Warnings about
                extraneous fields in request
     """

    output: 'KitchenSinkBulkProfileResponse200Output'
    charge_info: Union['KitchenSinkBulkProfileResponse200ChargeInfoType0', 'KitchenSinkBulkProfileResponse200ChargeInfoType1', 'KitchenSinkBulkProfileResponse200ChargeInfoType2', 'KitchenSinkBulkProfileResponse200ChargeInfoType3']
    warnings: Union[None, Unset, list['KitchenSinkBulkProfileResponse200WarningsType0Item']] = UNSET





    def to_dict(self) -> dict[str, Any]:
        from ..models.kitchen_sink_bulk_profile_response_200_warnings_type_0_item import KitchenSinkBulkProfileResponse200WarningsType0Item
        from ..models.kitchen_sink_bulk_profile_response_200_charge_info_type_0 import KitchenSinkBulkProfileResponse200ChargeInfoType0
        from ..models.kitchen_sink_bulk_profile_response_200_charge_info_type_3 import KitchenSinkBulkProfileResponse200ChargeInfoType3
        from ..models.kitchen_sink_bulk_profile_response_200_charge_info_type_1 import KitchenSinkBulkProfileResponse200ChargeInfoType1
        from ..models.kitchen_sink_bulk_profile_response_200_output import KitchenSinkBulkProfileResponse200Output
        from ..models.kitchen_sink_bulk_profile_response_200_charge_info_type_2 import KitchenSinkBulkProfileResponse200ChargeInfoType2
        output = self.output.to_dict()

        charge_info: dict[str, Any]
        if isinstance(self.charge_info, KitchenSinkBulkProfileResponse200ChargeInfoType0):
            charge_info = self.charge_info.to_dict()
        elif isinstance(self.charge_info, KitchenSinkBulkProfileResponse200ChargeInfoType1):
            charge_info = self.charge_info.to_dict()
        elif isinstance(self.charge_info, KitchenSinkBulkProfileResponse200ChargeInfoType2):
            charge_info = self.charge_info.to_dict()
        else:
            charge_info = self.charge_info.to_dict()


        warnings: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.warnings, Unset):
            warnings = UNSET
        elif isinstance(self.warnings, list):
            warnings = []
            for warnings_type_0_item_data in self.warnings:
                warnings_type_0_item = warnings_type_0_item_data.to_dict()
                warnings.append(warnings_type_0_item)


        else:
            warnings = self.warnings


        field_dict: dict[str, Any] = {}

        field_dict.update({
            "output": output,
            "chargeInfo": charge_info,
        })
        if warnings is not UNSET:
            field_dict["warnings"] = warnings

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.kitchen_sink_bulk_profile_response_200_warnings_type_0_item import KitchenSinkBulkProfileResponse200WarningsType0Item
        from ..models.kitchen_sink_bulk_profile_response_200_charge_info_type_0 import KitchenSinkBulkProfileResponse200ChargeInfoType0
        from ..models.kitchen_sink_bulk_profile_response_200_charge_info_type_3 import KitchenSinkBulkProfileResponse200ChargeInfoType3
        from ..models.kitchen_sink_bulk_profile_response_200_charge_info_type_1 import KitchenSinkBulkProfileResponse200ChargeInfoType1
        from ..models.kitchen_sink_bulk_profile_response_200_output import KitchenSinkBulkProfileResponse200Output
        from ..models.kitchen_sink_bulk_profile_response_200_charge_info_type_2 import KitchenSinkBulkProfileResponse200ChargeInfoType2
        d = dict(src_dict)
        output = KitchenSinkBulkProfileResponse200Output.from_dict(d.pop("output"))




        def _parse_charge_info(data: object) -> Union['KitchenSinkBulkProfileResponse200ChargeInfoType0', 'KitchenSinkBulkProfileResponse200ChargeInfoType1', 'KitchenSinkBulkProfileResponse200ChargeInfoType2', 'KitchenSinkBulkProfileResponse200ChargeInfoType3']:
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                charge_info_type_0 = KitchenSinkBulkProfileResponse200ChargeInfoType0.from_dict(data)



                return charge_info_type_0
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                charge_info_type_1 = KitchenSinkBulkProfileResponse200ChargeInfoType1.from_dict(data)



                return charge_info_type_1
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                charge_info_type_2 = KitchenSinkBulkProfileResponse200ChargeInfoType2.from_dict(data)



                return charge_info_type_2
            except: # noqa: E722
                pass
            if not isinstance(data, dict):
                raise TypeError()
            charge_info_type_3 = KitchenSinkBulkProfileResponse200ChargeInfoType3.from_dict(data)



            return charge_info_type_3

        charge_info = _parse_charge_info(d.pop("chargeInfo"))


        def _parse_warnings(data: object) -> Union[None, Unset, list['KitchenSinkBulkProfileResponse200WarningsType0Item']]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                warnings_type_0 = []
                _warnings_type_0 = data
                for warnings_type_0_item_data in (_warnings_type_0):
                    warnings_type_0_item = KitchenSinkBulkProfileResponse200WarningsType0Item.from_dict(warnings_type_0_item_data)



                    warnings_type_0.append(warnings_type_0_item)

                return warnings_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list['KitchenSinkBulkProfileResponse200WarningsType0Item']], data)

        warnings = _parse_warnings(d.pop("warnings", UNSET))


        kitchen_sink_bulk_profile_response_200 = cls(
            output=output,
            charge_info=charge_info,
            warnings=warnings,
        )

        return kitchen_sink_bulk_profile_response_200




from enum import Enum

class SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAnyType0ItemCountCriteriaType0Type(str, Enum):
    NUMERIC_CHANGE = "numeric_change"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum

class TextToProfileSearchParamsResponse200OutputSearchParamsLocationType0UnionAllType0ItemType0RadiusType0Unit(str, Enum):
    MILES = "miles"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.sync_combined_search_body_company_params_employee_trends_type_0_obeys_all_type_0_item_job_function import SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAllType0ItemJobFunction
from typing import cast
from typing import cast, Union

if TYPE_CHECKING:
  from ..models.sync_combined_search_body_company_params_employee_trends_type_0_obeys_all_type_0_item_count_criteria_type_1 import SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAllType0ItemCountCriteriaType1
  from ..models.sync_combined_search_body_company_params_employee_trends_type_0_obeys_all_type_0_item_count_criteria_type_2 import SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAllType0ItemCountCriteriaType2
  from ..models.sync_combined_search_body_company_params_employee_trends_type_0_obeys_all_type_0_item_count_criteria_type_0 import SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAllType0ItemCountCriteriaType0





T = TypeVar("T", bound="SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAllType0Item")



@_attrs_define
class SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAllType0Item:
    """ 
        Attributes:
            job_function (SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAllType0ItemJobFunction):
            count_criteria
                (Union['SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAllType0ItemCountCriteriaType0',
                'SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAllType0ItemCountCriteriaType1',
                'SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAllType0ItemCountCriteriaType2']):
     """

    job_function: SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAllType0ItemJobFunction
    count_criteria: Union['SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAllType0ItemCountCriteriaType0', 'SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAllType0ItemCountCriteriaType1', 'SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAllType0ItemCountCriteriaType2']
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.sync_combined_search_body_company_params_employee_trends_type_0_obeys_all_type_0_item_count_criteria_type_1 import SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAllType0ItemCountCriteriaType1
        from ..models.sync_combined_search_body_company_params_employee_trends_type_0_obeys_all_type_0_item_count_criteria_type_2 import SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAllType0ItemCountCriteriaType2
        from ..models.sync_combined_search_body_company_params_employee_trends_type_0_obeys_all_type_0_item_count_criteria_type_0 import SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAllType0ItemCountCriteriaType0
        job_function = self.job_function.value

        count_criteria: dict[str, Any]
        if isinstance(self.count_criteria, SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAllType0ItemCountCriteriaType0):
            count_criteria = self.count_criteria.to_dict()
        elif isinstance(self.count_criteria, SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAllType0ItemCountCriteriaType1):
            count_criteria = self.count_criteria.to_dict()
        else:
            count_criteria = self.count_criteria.to_dict()



        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "jobFunction": job_function,
            "countCriteria": count_criteria,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.sync_combined_search_body_company_params_employee_trends_type_0_obeys_all_type_0_item_count_criteria_type_1 import SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAllType0ItemCountCriteriaType1
        from ..models.sync_combined_search_body_company_params_employee_trends_type_0_obeys_all_type_0_item_count_criteria_type_2 import SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAllType0ItemCountCriteriaType2
        from ..models.sync_combined_search_body_company_params_employee_trends_type_0_obeys_all_type_0_item_count_criteria_type_0 import SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAllType0ItemCountCriteriaType0
        d = dict(src_dict)
        job_function = SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAllType0ItemJobFunction(d.pop("jobFunction"))




        def _parse_count_criteria(data: object) -> Union['SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAllType0ItemCountCriteriaType0', 'SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAllType0ItemCountCriteriaType1', 'SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAllType0ItemCountCriteriaType2']:
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                count_criteria_type_0 = SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAllType0ItemCountCriteriaType0.from_dict(data)



                return count_criteria_type_0
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                count_criteria_type_1 = SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAllType0ItemCountCriteriaType1.from_dict(data)



                return count_criteria_type_1
            except: # noqa: E722
                pass
            if not isinstance(data, dict):
                raise TypeError()
            count_criteria_type_2 = SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAllType0ItemCountCriteriaType2.from_dict(data)



            return count_criteria_type_2

        count_criteria = _parse_count_criteria(d.pop("countCriteria"))


        sync_combined_search_body_company_params_employee_trends_type_0_obeys_all_type_0_item = cls(
            job_function=job_function,
            count_criteria=count_criteria,
        )


        sync_combined_search_body_company_params_employee_trends_type_0_obeys_all_type_0_item.additional_properties = d
        return sync_combined_search_body_company_params_employee_trends_type_0_obeys_all_type_0_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import Union






T = TypeVar("T", bound="StartBatchContactEnrichmentBodyEnrichmentTypes")



@_attrs_define
class StartBatchContactEnrichmentBodyEnrichmentTypes:
    """ Types of contact info to be requested for each person. Include the ones you want to look for. For example, {
    getWorkEmails: true, getPersonalEmails: true, getPhoneNumbers: true }

        Attributes:
            get_work_emails (Union[Unset, bool]):  Default: True.
            get_personal_emails (Union[Unset, bool]):  Default: True.
            get_phone_numbers (Union[Unset, bool]):  Default: True.
     """

    get_work_emails: Union[Unset, bool] = True
    get_personal_emails: Union[Unset, bool] = True
    get_phone_numbers: Union[Unset, bool] = True
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        get_work_emails = self.get_work_emails

        get_personal_emails = self.get_personal_emails

        get_phone_numbers = self.get_phone_numbers


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if get_work_emails is not UNSET:
            field_dict["getWorkEmails"] = get_work_emails
        if get_personal_emails is not UNSET:
            field_dict["getPersonalEmails"] = get_personal_emails
        if get_phone_numbers is not UNSET:
            field_dict["getPhoneNumbers"] = get_phone_numbers

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        get_work_emails = d.pop("getWorkEmails", UNSET)

        get_personal_emails = d.pop("getPersonalEmails", UNSET)

        get_phone_numbers = d.pop("getPhoneNumbers", UNSET)

        start_batch_contact_enrichment_body_enrichment_types = cls(
            get_work_emails=get_work_emails,
            get_personal_emails=get_personal_emails,
            get_phone_numbers=get_phone_numbers,
        )


        start_batch_contact_enrichment_body_enrichment_types.additional_properties = d
        return start_batch_contact_enrichment_body_enrichment_types

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum

class CombinedSearchBodyProfileParamsJobTitleV2Type0AllOfType0ItemType2Type(str, Enum):
    DYNAMIC_GROUPS = "dynamic-groups"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Union

if TYPE_CHECKING:
  from ..models.create_saved_search_body_search_params_type_1_company_search_params_employees_type_0_rules_item_employees_to_match_type_0 import CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesType0RulesItemEmployeesToMatchType0
  from ..models.create_saved_search_body_search_params_type_1_company_search_params_employees_type_0_rules_item_employee_filters_type_0 import CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesType0RulesItemEmployeeFiltersType0
  from ..models.create_saved_search_body_search_params_type_1_company_search_params_employees_type_0_rules_item_employees_to_match_type_1 import CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesType0RulesItemEmployeesToMatchType1





T = TypeVar("T", bound="CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesType0RulesItem")



@_attrs_define
class CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesType0RulesItem:
    """ 
        Attributes:
            employees_to_match
                (Union['CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesType0RulesItemEmployeesToMatchType0',
                'CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesType0RulesItemEmployeesToMatchType1']):
            employee_filters
                (Union['CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesType0RulesItemEmployeeFiltersType0',
                None, Unset]):
     """

    employees_to_match: Union['CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesType0RulesItemEmployeesToMatchType0', 'CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesType0RulesItemEmployeesToMatchType1']
    employee_filters: Union['CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesType0RulesItemEmployeeFiltersType0', None, Unset] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.create_saved_search_body_search_params_type_1_company_search_params_employees_type_0_rules_item_employees_to_match_type_0 import CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesType0RulesItemEmployeesToMatchType0
        from ..models.create_saved_search_body_search_params_type_1_company_search_params_employees_type_0_rules_item_employee_filters_type_0 import CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesType0RulesItemEmployeeFiltersType0
        from ..models.create_saved_search_body_search_params_type_1_company_search_params_employees_type_0_rules_item_employees_to_match_type_1 import CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesType0RulesItemEmployeesToMatchType1
        employees_to_match: dict[str, Any]
        if isinstance(self.employees_to_match, CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesType0RulesItemEmployeesToMatchType0):
            employees_to_match = self.employees_to_match.to_dict()
        else:
            employees_to_match = self.employees_to_match.to_dict()


        employee_filters: Union[None, Unset, dict[str, Any]]
        if isinstance(self.employee_filters, Unset):
            employee_filters = UNSET
        elif isinstance(self.employee_filters, CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesType0RulesItemEmployeeFiltersType0):
            employee_filters = self.employee_filters.to_dict()
        else:
            employee_filters = self.employee_filters


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "employeesToMatch": employees_to_match,
        })
        if employee_filters is not UNSET:
            field_dict["employeeFilters"] = employee_filters

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.create_saved_search_body_search_params_type_1_company_search_params_employees_type_0_rules_item_employees_to_match_type_0 import CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesType0RulesItemEmployeesToMatchType0
        from ..models.create_saved_search_body_search_params_type_1_company_search_params_employees_type_0_rules_item_employee_filters_type_0 import CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesType0RulesItemEmployeeFiltersType0
        from ..models.create_saved_search_body_search_params_type_1_company_search_params_employees_type_0_rules_item_employees_to_match_type_1 import CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesType0RulesItemEmployeesToMatchType1
        d = dict(src_dict)
        def _parse_employees_to_match(data: object) -> Union['CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesType0RulesItemEmployeesToMatchType0', 'CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesType0RulesItemEmployeesToMatchType1']:
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                employees_to_match_type_0 = CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesType0RulesItemEmployeesToMatchType0.from_dict(data)



                return employees_to_match_type_0
            except: # noqa: E722
                pass
            if not isinstance(data, dict):
                raise TypeError()
            employees_to_match_type_1 = CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesType0RulesItemEmployeesToMatchType1.from_dict(data)



            return employees_to_match_type_1

        employees_to_match = _parse_employees_to_match(d.pop("employeesToMatch"))


        def _parse_employee_filters(data: object) -> Union['CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesType0RulesItemEmployeeFiltersType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                employee_filters_type_0 = CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesType0RulesItemEmployeeFiltersType0.from_dict(data)



                return employee_filters_type_0
            except: # noqa: E722
                pass
            return cast(Union['CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeesType0RulesItemEmployeeFiltersType0', None, Unset], data)

        employee_filters = _parse_employee_filters(d.pop("employeeFilters", UNSET))


        create_saved_search_body_search_params_type_1_company_search_params_employees_type_0_rules_item = cls(
            employees_to_match=employees_to_match,
            employee_filters=employee_filters,
        )


        create_saved_search_body_search_params_type_1_company_search_params_employees_type_0_rules_item.additional_properties = d
        return create_saved_search_body_search_params_type_1_company_search_params_employees_type_0_rules_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum

class CompanyCountBodySearchParamsJobPostingStatsType0NoneOfType0ItemType1RangeType1Type(str, Enum):
    PERCENT_RANGE = "percent-range"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.sync_combined_search_body_company_params_job_postings_v2_type_0_any_of_type_0_item_posted_at_type_1_strategy import SyncCombinedSearchBodyCompanyParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType1Strategy
from ..types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Union

if TYPE_CHECKING:
  from ..models.sync_combined_search_body_company_params_job_postings_v2_type_0_any_of_type_0_item_posted_at_type_1_window_type_0 import SyncCombinedSearchBodyCompanyParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType1WindowType0
  from ..models.sync_combined_search_body_company_params_job_postings_v2_type_0_any_of_type_0_item_posted_at_type_1_window_type_1 import SyncCombinedSearchBodyCompanyParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType1WindowType1
  from ..models.sync_combined_search_body_company_params_job_postings_v2_type_0_any_of_type_0_item_posted_at_type_1_window_type_2 import SyncCombinedSearchBodyCompanyParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType1WindowType2





T = TypeVar("T", bound="SyncCombinedSearchBodyCompanyParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType1")



@_attrs_define
class SyncCombinedSearchBodyCompanyParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType1:
    """ 
        Attributes:
            strategy (SyncCombinedSearchBodyCompanyParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType1Strategy):
            window (Union['SyncCombinedSearchBodyCompanyParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType1WindowType0',
                'SyncCombinedSearchBodyCompanyParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType1WindowType1',
                'SyncCombinedSearchBodyCompanyParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType1WindowType2', None, Unset]):
     """

    strategy: SyncCombinedSearchBodyCompanyParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType1Strategy
    window: Union['SyncCombinedSearchBodyCompanyParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType1WindowType0', 'SyncCombinedSearchBodyCompanyParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType1WindowType1', 'SyncCombinedSearchBodyCompanyParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType1WindowType2', None, Unset] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.sync_combined_search_body_company_params_job_postings_v2_type_0_any_of_type_0_item_posted_at_type_1_window_type_0 import SyncCombinedSearchBodyCompanyParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType1WindowType0
        from ..models.sync_combined_search_body_company_params_job_postings_v2_type_0_any_of_type_0_item_posted_at_type_1_window_type_1 import SyncCombinedSearchBodyCompanyParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType1WindowType1
        from ..models.sync_combined_search_body_company_params_job_postings_v2_type_0_any_of_type_0_item_posted_at_type_1_window_type_2 import SyncCombinedSearchBodyCompanyParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType1WindowType2
        strategy = self.strategy.value

        window: Union[None, Unset, dict[str, Any]]
        if isinstance(self.window, Unset):
            window = UNSET
        elif isinstance(self.window, SyncCombinedSearchBodyCompanyParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType1WindowType0):
            window = self.window.to_dict()
        elif isinstance(self.window, SyncCombinedSearchBodyCompanyParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType1WindowType1):
            window = self.window.to_dict()
        elif isinstance(self.window, SyncCombinedSearchBodyCompanyParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType1WindowType2):
            window = self.window.to_dict()
        else:
            window = self.window


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "strategy": strategy,
        })
        if window is not UNSET:
            field_dict["window"] = window

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.sync_combined_search_body_company_params_job_postings_v2_type_0_any_of_type_0_item_posted_at_type_1_window_type_0 import SyncCombinedSearchBodyCompanyParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType1WindowType0
        from ..models.sync_combined_search_body_company_params_job_postings_v2_type_0_any_of_type_0_item_posted_at_type_1_window_type_1 import SyncCombinedSearchBodyCompanyParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType1WindowType1
        from ..models.sync_combined_search_body_company_params_job_postings_v2_type_0_any_of_type_0_item_posted_at_type_1_window_type_2 import SyncCombinedSearchBodyCompanyParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType1WindowType2
        d = dict(src_dict)
        strategy = SyncCombinedSearchBodyCompanyParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType1Strategy(d.pop("strategy"))




        def _parse_window(data: object) -> Union['SyncCombinedSearchBodyCompanyParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType1WindowType0', 'SyncCombinedSearchBodyCompanyParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType1WindowType1', 'SyncCombinedSearchBodyCompanyParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType1WindowType2', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                window_type_0 = SyncCombinedSearchBodyCompanyParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType1WindowType0.from_dict(data)



                return window_type_0
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                window_type_1 = SyncCombinedSearchBodyCompanyParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType1WindowType1.from_dict(data)



                return window_type_1
            except: # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                window_type_2 = SyncCombinedSearchBodyCompanyParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType1WindowType2.from_dict(data)



                return window_type_2
            except: # noqa: E722
                pass
            return cast(Union['SyncCombinedSearchBodyCompanyParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType1WindowType0', 'SyncCombinedSearchBodyCompanyParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType1WindowType1', 'SyncCombinedSearchBodyCompanyParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType1WindowType2', None, Unset], data)

        window = _parse_window(d.pop("window", UNSET))


        sync_combined_search_body_company_params_job_postings_v2_type_0_any_of_type_0_item_posted_at_type_1 = cls(
            strategy=strategy,
            window=window,
        )


        sync_combined_search_body_company_params_job_postings_v2_type_0_any_of_type_0_item_posted_at_type_1.additional_properties = d
        return sync_combined_search_body_company_params_job_postings_v2_type_0_any_of_type_0_item_posted_at_type_1

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.check_google_maps_results_response_200_output_status import CheckGoogleMapsResultsResponse200OutputStatus






T = TypeVar("T", bound="CheckGoogleMapsResultsResponse200Output")



@_attrs_define
class CheckGoogleMapsResultsResponse200Output:
    """ 
        Attributes:
            status (CheckGoogleMapsResultsResponse200OutputStatus):
            total_places_found (int): The total number of places found
            total_places_requested (int): The total number of places requested
            percentage_completed (float): The percentage of places found
     """

    status: CheckGoogleMapsResultsResponse200OutputStatus
    total_places_found: int
    total_places_requested: int
    percentage_completed: float
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        status = self.status.value

        total_places_found = self.total_places_found

        total_places_requested = self.total_places_requested

        percentage_completed = self.percentage_completed


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "status": status,
            "totalPlacesFound": total_places_found,
            "totalPlacesRequested": total_places_requested,
            "percentageCompleted": percentage_completed,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        status = CheckGoogleMapsResultsResponse200OutputStatus(d.pop("status"))




        total_places_found = d.pop("totalPlacesFound")

        total_places_requested = d.pop("totalPlacesRequested")

        percentage_completed = d.pop("percentageCompleted")

        check_google_maps_results_response_200_output = cls(
            status=status,
            total_places_found=total_places_found,
            total_places_requested=total_places_requested,
            percentage_completed=percentage_completed,
        )


        check_google_maps_results_response_200_output.additional_properties = d
        return check_google_maps_results_response_200_output

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
